@@ -2,9 +2,20 @@ from PIL import Image, ImageDraw
 from collections import defaultdict
 import copy
 
-from .util import coordgen
+from .util import coordgen, nested_int_loop
 
 
+def get_target_color(img):
+    colorset = img.colorset()
+    if img.image.format.upper() == 'JPEG':
+        for i in range(256):
+            if i not in colorset:
+                return i
+    if img.image.format.upper() == 'PNG':
+        for color in nested_int_loop([256] * len(img.load()[0,0]))
+            if color not in colorset:
+                return color
+
 class ImageLayer:
     def __init__(self, image, pixelcoords=[], color=(0,0,0,255)):
         self.pxcs = set(pixelcoords)
@@ -123,20 +134,15 @@ class LayeredImage:
 
     def layersbyedge(self):
         orig = self.image.copy()
+        target_color = get_target_color(self)
         px = orig.load()
-
-        _value = {
-            'JPEG': (0,0,0),
-            'PNG': (0,0,0,0) 
-        }
-
         pixels = set()
         for x in range(orig.width):
             for y in range(orig.height):
                 if (x,y) in pixels:
                     continue
-                ImageDraw.floodfill(orig, xy=(x,y), value=_value.get(self.image.format.upper(), (0,0,0)))
-                group = filter(lambda x: px[x] == _value.get(self.image.format.upper(), (0,0,0)), coordgen(*orig.size))
+                ImageDraw.floodfill(orig, xy=(x,y), value=target_color)
+                group = filter(lambda x: px[x] == target_color, coordgen(*orig.size))
                 layer = ImageLayer(self.image, group, color=(255,255,255,255))
                 del group
                 for pixel in layer.pxcs:
